==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/digitaltwins/kotlin/inputs/ConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.digitaltwins.kotlin.inputs

import com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a private endpoint connection.
 * @property groupIds The list of group ids for the private endpoint connection.
 * @property privateLinkServiceConnectionState The connection state.
 */
public data class ConnectionPropertiesArgs(
    public val groupIds: Output<List<String>>? = null,
    public val privateLinkServiceConnectionState:
    Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs =
        com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs.builder()
            .groupIds(groupIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .privateLinkServiceConnectionState(
                privateLinkServiceConnectionState?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionPropertiesArgsBuilder internal constructor() {
    private var groupIds: Output<List<String>>? = null

    private var privateLinkServiceConnectionState:
        Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null

    /**
     * @param value The list of group ids for the private endpoint connection.
     */
    @JvmName("taaqhnyfnxwxkyhg")
    public suspend fun groupIds(`value`: Output<List<String>>) {
        this.groupIds = value
    }

    @JvmName("kvjfwgrhgbtvorqu")
    public suspend fun groupIds(vararg values: Output<String>) {
        this.groupIds = Output.all(values.asList())
    }

    /**
     * @param values The list of group ids for the private endpoint connection.
     */
    @JvmName("cgisdpgxuccxyeui")
    public suspend fun groupIds(values: List<Output<String>>) {
        this.groupIds = Output.all(values)
    }

    /**
     * @param value The connection state.
     */
    @JvmName("ksjcahifuhirarlg")
    public suspend
    fun privateLinkServiceConnectionState(`value`: Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>) {
        this.privateLinkServiceConnectionState = value
    }

    /**
     * @param value The list of group ids for the private endpoint connection.
     */
    @JvmName("seajelkaxadqvfvr")
    public suspend fun groupIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param values The list of group ids for the private endpoint connection.
     */
    @JvmName("maayscbxgjhpgpxn")
    public suspend fun groupIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param value The connection state.
     */
    @JvmName("sdahibynaahifvhr")
    public suspend
    fun privateLinkServiceConnectionState(`value`: ConnectionPropertiesPrivateLinkServiceConnectionStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param argument The connection state.
     */
    @JvmName("sladwljeyiexvphs")
    public suspend
    fun privateLinkServiceConnectionState(argument: suspend ConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder.() -> Unit) {
        val toBeMapped =
            ConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.privateLinkServiceConnectionState = mapped
    }

    internal fun build(): ConnectionPropertiesArgs = ConnectionPropertiesArgs(
        groupIds = groupIds,
        privateLinkServiceConnectionState = privateLinkServiceConnectionState,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/digitaltwins/kotlin/inputs/ConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.digitaltwins.kotlin.inputs

import com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a private endpoint connection.
 * @property groupIds The list of group ids for the private endpoint connection.
 * @property privateLinkServiceConnectionState The connection state.
 */
public data class ConnectionPropertiesArgs(
    public val groupIds: Output<List<String>>? = null,
    public val privateLinkServiceConnectionState:
    Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs =
        com.pulumi.azurenative.digitaltwins.inputs.ConnectionPropertiesArgs.builder()
            .groupIds(groupIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .privateLinkServiceConnectionState(
                privateLinkServiceConnectionState?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionPropertiesArgsBuilder internal constructor() {
    private var groupIds: Output<List<String>>? = null

    private var privateLinkServiceConnectionState:
        Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null

    /**
     * @param value The list of group ids for the private endpoint connection.
     */
    @JvmName("eqjfwniycoakedlo")
    public suspend fun groupIds(`value`: Output<List<String>>) {
        this.groupIds = value
    }

    @JvmName("ocmbaamrhjdfdjbi")
    public suspend fun groupIds(vararg values: Output<String>) {
        this.groupIds = Output.all(values.asList())
    }

    /**
     * @param values The list of group ids for the private endpoint connection.
     */
    @JvmName("gfuiynejumonauit")
    public suspend fun groupIds(values: List<Output<String>>) {
        this.groupIds = Output.all(values)
    }

    /**
     * @param value The connection state.
     */
    @JvmName("xuplkeisjbqjxoib")
    public suspend
    fun privateLinkServiceConnectionState(`value`: Output<ConnectionPropertiesPrivateLinkServiceConnectionStateArgs>) {
        this.privateLinkServiceConnectionState = value
    }

    /**
     * @param value The list of group ids for the private endpoint connection.
     */
    @JvmName("iwyskdulhnagcble")
    public suspend fun groupIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param values The list of group ids for the private endpoint connection.
     */
    @JvmName("qbbenyjhucpxbnwd")
    public suspend fun groupIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param value The connection state.
     */
    @JvmName("wkjwgxnuxtiebego")
    public suspend
    fun privateLinkServiceConnectionState(`value`: ConnectionPropertiesPrivateLinkServiceConnectionStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param argument The connection state.
     */
    @JvmName("tbafeurfvcpmwxmc")
    public suspend
    fun privateLinkServiceConnectionState(argument: suspend ConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder.() -> Unit) {
        val toBeMapped =
            ConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.privateLinkServiceConnectionState = mapped
    }

    internal fun build(): ConnectionPropertiesArgs = ConnectionPropertiesArgs(
        groupIds = groupIds,
        privateLinkServiceConnectionState = privateLinkServiceConnectionState,
    )
}
